==> bouml_2.26.3.orig.tar.gz: bouml_2.26.3/src/JavaGenerator/UmlArtifact.h <==
// *************************************************************************
//
// Copyleft 2004-2007 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLARTIFACT_H
#define UMLARTIFACT_H

#include <qasciidict.h> 

#include "UmlBaseArtifact.h"

class UmlPackage;

// This class manages 'artifacts'
// You can modify it as you want (except the constructor)

class UmlArtifact : public UmlBaseArtifact {
  private:
    bool managed;
    QAsciiDict<UmlArtifact> * imports;
    
    static UmlArtifact * current;
    static UmlPackage * package_of_generated_artifact;
    
    static bool must_be_saved(const char * path, const char * new_contains);
  
  public:
    UmlArtifact(void * id, const QCString & n)
      : UmlBaseArtifact(id, n), managed(FALSE), imports(0) {};
    
    virtual void generate();
    
    bool imported(QCString pack_name, QCString class_name);
    
    static UmlArtifact * generated_one();
    static UmlPackage * generation_package();
};

#endif

==> bouml_4.16.2.orig.tar.gz: bouml_4.16.2/src/JavaGenerator/UmlArtifact.h <==
// *************************************************************************
//
// Copyright 2004-2009 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLARTIFACT_H
#define UMLARTIFACT_H

#include <qasciidict.h> 

#include "UmlBaseArtifact.h"

class UmlPackage;

// This class manages 'artifacts'
// You can modify it as you want (except the constructor)

class UmlArtifact : public UmlBaseArtifact {
  private:
    bool managed;
    QAsciiDict<UmlArtifact> * imports;
    
    static UmlArtifact * current;
    static UmlPackage * package_of_generated_artifact;
    
    static bool must_be_saved(const char * path, const char * new_contains);
  
    void generate_text();

  public:
    UmlArtifact(void * id, const QCString & n)
      : UmlBaseArtifact(id, n), managed(FALSE), imports(0) {};
    
    virtual void generate();
    
    void imported(QCString s);
    bool is_imported(QCString path, QCString class_name);
    
    static UmlArtifact * generated_one();
    static UmlPackage * generation_package();
};

#endif
